@@ -291,9 +291,9 @@ class JinjaStaticRenderer():
             "directory",
             {
                 'input_dir': self.config['input_dir'],
-                'valid_extensions': self.config['extensions'],
                 'ignore_files': self.config['ignore'],
-                'item_class': Page
+                'item_class': Page,
+                'data_format': self.config['data_format']
             }
         )
 
