@@ -14,7 +14,7 @@ defaults = {
         "output_file_extension": "html",
         "output_dir": "www",
         "input_dir": "site",
-        "extensions": ["json"],
+        "data_format": "json",
         "ignore": [".", "_"],
         "site_vars":"env",
         "verbose": "false",
